Documentation
¶
Index ¶
- type Global
- func (p *Global) Add(pkgSymbols *Package)
- func (p *Global) Composer() *symbols.Composer
- func (p *Global) GetPackage(pkg *packages.Package) *Package
- func (p *Global) GetPkgSymbol(pkg *packages.Package) (string, bool)
- func (p *Global) GetPkgSymbolByID(pkgID newtypes.PackageID) (string, bool)
- func (p *Global) GetSymbol(pkg *packages.Package, pos token.Pos) (string, bool)
- func (p *Global) GetSymbolInformation(pkg *packages.Package, pos token.Pos) (*scip.SymbolInformation, bool)
- func (p *Global) GetSymbolOfObject(obj types.Object) (*scip.SymbolInformation, bool, error)
- func (p *Global) SetPkgSymbol(pkg *packages.Package) string
- type Local
- type Package
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Global ¶
type Global struct {
// contains filtered or unexported fields
}
func NewGlobalSymbols ¶
func (*Global) GetPkgSymbolByID ¶
func (*Global) GetSymbolInformation ¶
func (*Global) GetSymbolOfObject ¶
GetSymbolOfObject returns a symbol and whether we were successful at finding.
We can return an empty string if this object should be ignored.
type Local ¶
Local contains information about a local symbol
func (*Local) SignatureText ¶
SignatureText builds a concise signature string for this local symbol.
type Package ¶
type Package struct {
// contains filtered or unexported fields
}
func NewPackageSymbols ¶
func (*Package) SymbolsForFile ¶
func (p *Package) SymbolsForFile(file *token.File) []*scip.SymbolInformation
Click to show internal directories.
Click to hide internal directories.